@@ -1,4 +1,14 @@
 from mvvmQt.Elements import Element
+import uuid
+
+def setStyleSheet(*params):
+    v = params[0]
+    o: Element = params[-2]
+    token = uuid.uuid1()
+
+    o.qt.setObjectName("%s" % token)
+    style = "QFrame#%s{%s}" % (token, v)
+    o.qt.setStyleSheet(style)
 
 def __updateObValue(ob, v, t):
     if t == bool:
@@ -19,6 +29,19 @@ def groupChecked(*params):
 
     o.qt.buttons()[int(v)].setChecked(True)
 
+def indexChanged(*params):
+    v = params[0]
+    o: Element = params[-2]
+    ob = params[-1]
+
+    attr = list(filter(lambda _: _.key == 'index', o.attrs))[0]
+
+    if attr.twoWay and not getattr(o.qt, '_bindChanged', False):
+        o.qt.currentIndexChanged[int].connect(lambda id: __updateObValue(ob, id, type(v)))
+        o.qt._bindChanged = True
+
+    o.qt.setCurrentIndex(v)
+
 def htmlChanged(*params):
     v = params[0]
     o: Element = params[-2]
